@@ -1,12 +1,12 @@
 use std::path::{ PathBuf };
 use super::build_file_structure_trait::*;
-use std::fs::{ create_dir, File };
+use std::fs::{ create_dir, create_dir_all, File };
 use std::io::Write;
 
 impl BuildFileStructure for PathBuf {
     fn create_dir_if_not_exist(&self, message: &str) {
         if !self.exists() {
-            create_dir(self)
+            create_dir_all(self)
                 .unwrap_or_else(|_| panic!("{}.\nPath: {:?}\n", message, self));
         }
     }
